@@ -49,6 +49,7 @@
 #'   show.values = FALSE, show.p = FALSE, p.shape = TRUE
 #' )
 #'
+#' \dontrun{
 #' # plot multiple models from nested lists argument
 #' all.models <- list()
 #' all.models[[1]] <- fit1
@@ -64,13 +65,9 @@
 #' fit3 <- update(fit2, . ~ . + am)
 #'
 #' plot_models(fit1, fit2, fit3, std.est = "std2")
-#'
+#' }
 #' @import ggplot2
-#' @importFrom purrr map map_df map2
-#' @importFrom dplyr slice bind_rows filter
-#' @importFrom sjlabelled response_labels term_labels
 #' @importFrom rlang .data
-#' @importFrom sjmisc word_wrap var_rename add_variables
 #' @export
 plot_models <- function(...,
                         transform = NULL,
@@ -111,7 +108,7 @@ plot_models <- function(...,
                         prefix.labels = c("none", "varname", "label")) {
   # retrieve list of fitted models
   input_list <- list(...)
-  names(input_list) <- unlist(lapply(match.call(expand.dots = F)$`...`, deparse))
+  names(input_list) <- unlist(lapply(match.call(expand.dots = FALSE)$`...`, deparse))
 
   vcov.type <- match.arg(vcov.type)
 
@@ -127,9 +124,17 @@ plot_models <- function(...,
   if (missing(value.size) || is.null(value.size)) value.size <- 4
 
   # check length. if we have a list of fitted model, we need to "unlist" them
-  if (length(input_list) == 1 && class(input_list[[1]]) == "list")
+  if (length(input_list) == 1 && inherits(input_list[[1]], "list"))
     input_list <- purrr::map(input_list[[1]], ~ .x)
 
+  # check input if really models
+  is_model <- vapply(input_list, insight::is_model, logical(1))
+  if (!all(is_model)) {
+    insight::format_error(
+      "Some of the provided objects were not recognized as regression models.",
+      "Maybe you are using invalid function arguments? Please check the documentation (`?plot_models`) and your code."
+    )
+  }
 
   # get info on model family
   fam.info <- insight::model_info(input_list[[1]])
@@ -140,12 +145,14 @@ plot_models <- function(...,
   # check whether estimates should be transformed or not
 
   if (missing(transform)) {
-    if (fam.info$is_linear)
+    if (fam.info$is_linear) {
       tf <- NULL
-    else
+    } else {
       tf <- "exp"
-  } else
+    }
+  } else {
     tf <- transform
+  }
 
 
   # check for standardization, only applies to linear models
@@ -178,8 +185,7 @@ plot_models <- function(...,
       bootstrap = FALSE,
       iterations = 1000,
       seed = NULL,
-      p_adjust = p.adjust,
-      ...
+      p_adjust = p.adjust
     )
   )
 
@@ -212,7 +218,9 @@ plot_models <- function(...,
 
 
   # add grouping index
-  for (i in 1:length(fl)) fl[[i]] <- sjmisc::add_variables(fl[[i]], group = as.character(i), .after = Inf)
+  for (i in seq_along(fl)) {
+    fl[[i]] <- sjmisc::add_variables(fl[[i]], group = as.character(i), .after = Inf)
+  }
 
   # merge models to one data frame
   ff <- dplyr::bind_rows(fl)
